#### What

- [x] Please list what you did on this merge request.

<!-- Add screenshots here if necessary or use some
colums:

| First Column | Second Column| Third Column |
|--------------|--------------|--------------|
| picture-here | picture-here | picture-here |
-->

#### Why

Explain why the proposed change is necessary.


#### Reminders

- [x] My Pull Request is up to date with the main branch
- [ ] My PR build is 🟢
- [ ] This PR is not too big to be revised
- [ ] I added tests that cover success and error cases (if applicable)

<!-- #### Reminders

- PR title: type: <Title here>
  - Type is related to semantic release e.g. feat fix tests styles chore
- Tests have been added and are passing
- Lint is passing
- Dependencies are up to date.
- Review your own code before submitting the merge request.
- All env vars which are being used have been added to:
  - [`local.env`](local.env)
  - [`ci file`](.github/workflows/test.yaml)-->
